zfilepath

package
v0.0.0-...-8c08148 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 23, 2026 License: MIT Imports: 2 Imported by: 6

Documentation

Overview

Package zfilepath implements functions for manipulating filename paths.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SplitExt

func SplitExt(path string) (string, string)

SplitExt returns the path without extension and the extension.

If there is no extension the first return value is the same as the input. The extension will *not* contain a dot.

func TrimPrefix

func TrimPrefix(path, prefix string) string

TrimPrefix trims a prefix from a path.

This ensures that any trailing slashes are also removed.

Types

This section is empty.

Jump to