Documentation
¶
Overview ¶
Package zfilepath implements functions for manipulating filename paths.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SplitExt ¶
SplitExt returns the path without extension and the extension.
If there is no extension the first return value is the same as the input. The extension will *not* contain a dot.
func TrimPrefix ¶
TrimPrefix trims a prefix from a path.
This ensures that any trailing slashes are also removed.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.